@@ -82,9 +82,21 @@ class KeystoneStrategy(BaseStrategy):
            case, we rewrite the url to contain /v2.0/ and retry using the v2
            protocol.
         """
-        def _authenticate(auth_url):
-            token_url = urlparse.urljoin(auth_url, "tokens")
+        def check_auth_params():
+            # Ensure that supplied credential parameters are as required
+            for required in ('username', 'password', 'auth_url'):
+                if required not in self.creds:
+                    raise exception.MissingCredentialError(required=required)
+            # For v2.0 also check tenant is present
+            if self.creds['auth_url'].rstrip('/').endswith('v2.0'):
+                if 'tenant' not in self.creds:
+                    raise exception.MissingCredentialError(required='tenant')
 
+        def _authenticate(auth_url):
+            # If OS_AUTH_URL is missing a trailing slash add one
+            if not auth_url.endswith('/'):
+                auth_url += '/'
+            token_url = urlparse.urljoin(auth_url, "tokens")
             # 1. Check Keystone version
             is_v2 = auth_url.rstrip('/').endswith('v2.0')
             if is_v2:
@@ -92,11 +104,7 @@ class KeystoneStrategy(BaseStrategy):
             else:
                 self._v1_auth(token_url)
 
-        for required in ('username', 'password', 'auth_url'):
-            if required not in self.creds:
-                raise Exception(_("'%s' must be included in creds") %
-                                required)
-
+        check_auth_params()
         auth_url = self.creds['auth_url']
         for _ in range(self.MAX_REDIRECTS):
             try:
@@ -140,20 +148,27 @@ class KeystoneStrategy(BaseStrategy):
                 raise exception.AuthorizationFailure()
         elif resp.status == 305:
             raise exception.RedirectException(resp['location'])
+        elif resp.status == 400:
+            raise exception.AuthBadRequest()
         elif resp.status == 401:
             raise exception.NotAuthorized()
+        elif resp.status == 404:
+            raise exception.AuthUrlNotFound(url=token_url)
         else:
             raise Exception(_('Unexpected response: %s' % resp.status))
 
     def _v2_auth(self, token_url):
         creds = self.creds
 
-        creds = {"passwordCredentials": {"username": creds['username'],
-                                         "password": creds['password']}}
-
-        tenant = creds.get('tenant')
-        if tenant:
-            creds['passwordCredentials']['tenantId'] = tenant
+        creds = {
+            "auth": {
+                "tenantName": creds['tenant'],
+                "passwordCredentials": {
+                    "username": creds['username'],
+                    "password": creds['password']
+                    }
+                }
+            }
 
         headers = {}
         headers['Content-Type'] = 'application/json'
@@ -163,19 +178,27 @@ class KeystoneStrategy(BaseStrategy):
                 token_url, 'POST', headers=headers, body=req_body)
 
         if resp.status == 200:
-            resp_auth = json.loads(resp_body)['auth']
+            resp_auth = json.loads(resp_body)['access']
 
             # FIXME(sirp): for now just using the first endpoint we get back
             # from the service catalog for glance, and using the public url.
-            glance_info = resp_auth['serviceCatalog']['glance']
-            glance_endpoint = glance_info[0]['publicURL']
+            for service in resp_auth['serviceCatalog']:
+                if service['name'] == 'glance':
+                    glance_endpoint = service['endpoints'][0]['publicURL']
+                    break
+            else:
+                raise exception.NoServiceEndpoint()
 
             self.management_url = glance_endpoint
             self.auth_token = resp_auth['token']['id']
         elif resp.status == 305:
             raise RedirectException(resp['location'])
+        elif resp.status == 400:
+            raise exception.AuthBadRequest()
         elif resp.status == 401:
             raise exception.NotAuthorized()
+        elif resp.status == 404:
+            raise exception.AuthUrlNotFound(url=token_url)
         else:
             raise Exception(_('Unexpected response: %s') % resp.status)
 
