@@ -18,10 +18,10 @@
 import datetime
 import json
 import os
-import stubout
 import StringIO
 import unittest
 
+import stubout
 import webob
 
 from glance import client
@@ -560,7 +560,6 @@ class TestRegistryClient(unittest.TestCase):
                    'container_format': 'ovf',
                    'status': 'active',
                    'size': 19,
-                   'location': "file:///tmp/glance-tests/2",
                    'properties': {}}
 
         images = self.client.get_images_detailed()
@@ -787,7 +786,6 @@ class TestRegistryClient(unittest.TestCase):
                    'container_format': 'ami',
                    'status': 'active',
                    'size': 13,
-                   'location': "swift://user:passwd@acct/container/obj.tar.0",
                    'properties': {'type': 'kernel'}}
 
         data = self.client.get_image(1)
@@ -811,7 +809,6 @@ class TestRegistryClient(unittest.TestCase):
                    'disk_format': 'vmdk',
                    'container_format': 'ovf',
                    'size': 19,
-                   'location': "file:///tmp/glance-tests/acct/3.gz.0",
                   }
 
         new_image = self.client.add_image(fixture)
@@ -844,6 +841,7 @@ class TestRegistryClient(unittest.TestCase):
         # Test ID auto-assigned properly
         self.assertEquals(3, new_image['id'])
 
+        del fixture['location']
         for k, v in fixture.items():
             self.assertEquals(v, new_image[k])
 
@@ -977,7 +975,7 @@ class TestClient(unittest.TestCase):
         stubs.stub_out_registry_and_store_server(self.stubs)
         stubs.stub_out_filesystem_backend()
         db_api.configure_db(OPTIONS)
-        self.client = client.Client("0.0.0.0", doc_root="")
+        self.client = client.Client("0.0.0.0")
         self.FIXTURES = [
             {'id': 1,
              'name': 'fake image #1',
@@ -1377,6 +1375,7 @@ class TestClient(unittest.TestCase):
         # Test all other attributes set
         data = self.client.get_image_meta(3)
 
+        del fixture['location']
         for k, v in fixture.items():
             self.assertEquals(v, data[k])
 
@@ -1415,6 +1414,7 @@ class TestClient(unittest.TestCase):
         # Test all other attributes set
         data = self.client.get_image_meta(3)
 
+        del fixture['location']
         for k, v in fixture.items():
             self.assertEquals(v, data[k])
 
@@ -1441,6 +1441,7 @@ class TestClient(unittest.TestCase):
         # Test all other attributes set
         data = self.client.get_image_meta(3)
 
+        del fixture['location']
         for k, v in fixture.items():
             self.assertEquals(v, data[k])
 
@@ -1467,6 +1468,7 @@ class TestClient(unittest.TestCase):
         # Test all other attributes set
         data = self.client.get_image_meta(3)
 
+        del fixture['location']
         for k, v in fixture.items():
             self.assertEquals(v, data[k])
 
